"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shuffle = exports.hash = exports.filename = exports.extension = exports.encrypt = exports.decrypt = exports.base64Decode = exports.base64Encode = void 0;
const fs_1 = require("fs");
const crypto_1 = require("crypto");
const chars = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'];
const numbers = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
const symbols = ['@', '#', '&', '$', '.'];
const algorithm = 'aes-256-cbc';
const key = crypto_1.randomBytes(32);
const iv = crypto_1.randomBytes(16);
const shuffle = (a) => {
    for (let i = a.length - 1; i > 0; i--) {
        const j = Math.floor(Math.random() * (i + 1));
        [a[i], a[j]] = [a[j], a[i]];
    }
    return a.join('');
};
exports.shuffle = shuffle;
const hash = (str, length) => {
    const array = str.split('').concat(chars).concat(numbers).concat(symbols);
    return shuffle(array).substr(0, length);
};
exports.hash = hash;
const base64Encode = (path) => {
    const stream = fs_1.readFileSync(path);
    return stream.toString('base64');
};
exports.base64Encode = base64Encode;
const base64Decode = (stream, path) => {
    const size = stream.toString('ascii').length;
    fs_1.writeFileSync(path, Buffer.alloc(size, stream, 'ascii'));
};
exports.base64Decode = base64Decode;
const decrypt = (cipherText) => {
    const decipher = crypto_1.createDecipheriv(algorithm, key, iv);
    return decipher.update(cipherText, 'hex', 'utf8') + decipher.final('utf8');
};
exports.decrypt = decrypt;
const encrypt = (text) => {
    const cipher = crypto_1.createCipheriv(algorithm, key, iv);
    return cipher.update(text, 'utf8', 'hex') + cipher.final('hex');
};
exports.encrypt = encrypt;
const filename = (name) => {
    return name.lastIndexOf('.') !== -1 ? name.substring(0, name.lastIndexOf('.')) : name;
};
exports.filename = filename;
const extension = (name, include = false) => {
    return name.lastIndexOf('.') !== -1 ? include === true ? name.substring(name.lastIndexOf('.')) : name.substring(name.lastIndexOf('.') + 1) : name;
};
exports.extension = extension;
